"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// index.ts
var ac_remix_dynamic_scripts_exports = {};
__export(ac_remix_dynamic_scripts_exports, {
  getProviderScript: () => getProviderScript,
  useDynamicScripts: () => useDynamicScripts
});
module.exports = __toCommonJS(ac_remix_dynamic_scripts_exports);

// src/injectScripts.ts
function getProviderScript(providerName, projectIdOrScript) {
  const validateCustomScript = (script) => {
    try {
      new Function(script);
    } catch (e) {
      if (e instanceof SyntaxError) {
        console.log(`Invalid custom script: ${e.message}`);
      }
      console.log(e);
    }
  };
  const providerScripts = {
    helpscout: (id) => `!function(e,t,n){function a(){var e=t.getElementsByTagName("script")[0],n=t.createElement("script");n.type="text/javascript",n.async=!0,n.src="https://beacon-v2.helpscout.net",e.parentNode.insertBefore(n,e)}if(e.Beacon=n=function(t,n,a){e.Beacon.readyQueue.push({method:t,options:n,data:a})},n.readyQueue=[],"complete"===t.readyState)return a();e.attachEvent?e.attachEvent("onload",a):e.addEventListener("load",a,!1)}(window,document,window.Beacon||function(){});
      window.Beacon('init', '${id}');
    `,
    clarityms: (id) => `
      (function(c,l,a,r,i,t,y){
        c[a]=c[a]||function(){(c[a].q=c[a].q||[]).push(arguments)};
        t=l.createElement(r);t.async=1;t.src="https://www.clarity.ms/tag/"+i;
        y=l.getElementsByTagName(r)[0];y.parentNode.insertBefore(t,y);
      })(window, document, "clarity", "script", "${id}");
    `,
    proprofs_livechat: (id) => `
      (function(){
        var pp=document.createElement('script'), ppr=document.getElementsByTagName('script')[0];
        stid='${id}';pp.type='text/javascript'; pp.async=true; 
        pp.src=('https:' == document.location.protocol ? 'https://' : 'http://') + 's01.live2support.com/dashboardv2/chatwindow/';
        ppr.parentNode.insertBefore(pp, ppr);
      })();
    `,
    // Custom script
    custom: (script) => {
      validateCustomScript(script);
      return script;
    }
  };
  try {
    const generator = providerScripts[providerName.toLowerCase()];
    if (!generator) {
      console.log(
        `Unsupported provider: ${providerName}. Add a script generator for this provider or use "custom" for raw scripts.`
      );
    }
    return generator(projectIdOrScript);
  } catch (error) {
    console.error(error);
    return "";
  }
}

// src/useDynamicScripts.ts
var import_react = require("react");
var injectedScripts = /* @__PURE__ */ new Set();
function useDynamicScripts(providerScripts) {
  (0, import_react.useEffect)(() => {
    providerScripts.forEach((scriptContent) => {
      if (!scriptContent || injectedScripts.has(scriptContent) || !document) {
        return;
      }
      const script = document.createElement("script");
      script.setAttribute(
        "id",
        `ac-dynamic-script-${injectedScripts.size + 1}`
      );
      script.type = "text/javascript";
      script.async = true;
      script.text = scriptContent;
      document.head.appendChild(script);
    });
    return () => {
      providerScripts.forEach((_, index) => {
        const script = document.head.querySelector(
          `script[data-dynamic="true"]:nth-of-type(${index + 1})`
        );
        if (script) script.remove();
      });
    };
  }, [providerScripts]);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getProviderScript,
  useDynamicScripts
});
//# sourceMappingURL=index.js.map