// src/injectScripts.ts
function getProviderScript(providerName, projectIdOrScript) {
  const validateCustomScript = (script) => {
    try {
      new Function(script);
    } catch (e) {
      if (e instanceof SyntaxError) {
        console.log(`Invalid custom script: ${e.message}`);
      }
      console.log(e);
    }
  };
  const providerScripts = {
    helpscout: (id) => `!function(e,t,n){function a(){var e=t.getElementsByTagName("script")[0],n=t.createElement("script");n.type="text/javascript",n.async=!0,n.src="https://beacon-v2.helpscout.net",e.parentNode.insertBefore(n,e)}if(e.Beacon=n=function(t,n,a){e.Beacon.readyQueue.push({method:t,options:n,data:a})},n.readyQueue=[],"complete"===t.readyState)return a();e.attachEvent?e.attachEvent("onload",a):e.addEventListener("load",a,!1)}(window,document,window.Beacon||function(){});
      window.Beacon('init', '${id}');
    `,
    clarityms: (id) => `
      (function(c,l,a,r,i,t,y){
        c[a]=c[a]||function(){(c[a].q=c[a].q||[]).push(arguments)};
        t=l.createElement(r);t.async=1;t.src="https://www.clarity.ms/tag/"+i;
        y=l.getElementsByTagName(r)[0];y.parentNode.insertBefore(t,y);
      })(window, document, "clarity", "script", "${id}");
    `,
    proprofs_livechat: (id) => `
      (function(){
        var pp=document.createElement('script'), ppr=document.getElementsByTagName('script')[0];
        stid='${id}';pp.type='text/javascript'; pp.async=true; 
        pp.src=('https:' == document.location.protocol ? 'https://' : 'http://') + 's01.live2support.com/dashboardv2/chatwindow/';
        ppr.parentNode.insertBefore(pp, ppr);
      })();
    `,
    // Custom script
    custom: (script) => {
      validateCustomScript(script);
      return script;
    }
  };
  try {
    const generator = providerScripts[providerName.toLowerCase()];
    if (!generator) {
      console.log(
        `Unsupported provider: ${providerName}. Add a script generator for this provider or use "custom" for raw scripts.`
      );
    }
    return generator(projectIdOrScript);
  } catch (error) {
    console.error(error);
    return "";
  }
}

// src/useDynamicScripts.ts
import { useEffect } from "react";
var injectedScripts = /* @__PURE__ */ new Set();
function useDynamicScripts(providerScripts) {
  useEffect(() => {
    providerScripts.forEach((scriptContent) => {
      if (!scriptContent || injectedScripts.has(scriptContent) || !document) {
        return;
      }
      const script = document.createElement("script");
      script.setAttribute(
        "id",
        `ac-dynamic-script-${injectedScripts.size + 1}`
      );
      script.type = "text/javascript";
      script.async = true;
      script.text = scriptContent;
      document.head.appendChild(script);
    });
    return () => {
      providerScripts.forEach((_, index) => {
        const script = document.head.querySelector(
          `script[data-dynamic="true"]:nth-of-type(${index + 1})`
        );
        if (script) script.remove();
      });
    };
  }, [providerScripts]);
}
export {
  getProviderScript,
  useDynamicScripts
};
//# sourceMappingURL=index.mjs.map